import {StepInfoNode} from "../../model/tactic/Tactic";
import "../../style/steps-tree.css"
import BendableArrow from "../arrows/BendableArrow";
import {useRef} from "react";

export interface StepsTreeProps {
    root: StepInfoNode
}

export default function StepsTree({root}: StepsTreeProps) {
    return <div className="steps-tree">
        <StepsTreeNode node={root}/>
    </div>
}

interface StepsTreeContentProps {
    node: StepInfoNode
}

function StepsTreeNode({node}: StepsTreeContentProps) {
    const ref = useRef<HTMLDivElement>(null)
    return (
        <div ref={ref}
             className={"step-group"}>
            <StepPiece id={node.id}/>
            {node.children.map(child => (
                <BendableArrow
                    key={child.id}
                    area={ref}
                    startPos={"step-piece-" + node.id}
                    segments={[{next: "step-piece-" + child.id}]}
                    onSegmentsChanges={() => {
                    }}
                    forceStraight={true}
                    wavy={false}
                    //TODO remove magic constant
                    startRadius={10}
                    endRadius={10}
                />
            ))}
            <div className={"step-children"}>
                {node.children.map(child => <StepsTreeNode key={child.id} node={child}/>)}
            </div>
        </div>
    )
}

interface StepPieceProps {
    id: number
}

function StepPiece({id}: StepPieceProps) {
    return (
        <div id={"step-piece-" + id} className={"step-piece"}>
            <p>{id}</p>
        </div>
    )
}
